# Authorisation complete!

Awesome — analytix is now authorised! You may now close this window.

## What happens now?

Your tokens will be saved to the file path you specified. If you did not specify a file path, you will find them in a JSON file named after the project ID of your Google Developers application in your current working directory.
Your new tokens will serve you well for the next 7 days, unless your application status is anything other than "Testing". If you do not know whether your application's status is "Testing", it more than likely is. You can find more information regarding the lifetime of tokens on the Google Identity documentation.